@@ -28,16 +28,16 @@
 #include <tqpushbutton.h>
 #include <tqslider.h>
 
-class KXMLGUIClient; // workaround for trinity.3 on sarge with gcc4, kactioncollection.h does not forward declare KXMLGUIClient
+class KXMLGUIClient; // workaround for trinity.3 on sarge with gcc4, tdeactioncollection.h does not forward declare KXMLGUIClient
 #include <klibloader.h>
 #include <kdebug.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <ksimpleconfig.h>
-#include <kaction.h>
-#include <kapplication.h>
-#include <klocale.h>
+#include <tdeaction.h>
+#include <tdeapplication.h>
+#include <tdelocale.h>
 #include <kinstance.h>
-#include <kparts/factory.h>
+#include <tdeparts/factory.h>
 #include <kstaticdeleter.h>
 #include <kstatusbar.h>
 
@@ -100,17 +100,17 @@ public:
         (TQWidget *wparent, const char *wname,
          TQObject *parent, const char *name,
          const char *className, const TQStringList &args);
-    static KInstance * instance () { return s_instance; }
+    static TDEInstance * instance () { return s_instance; }
 private:
-    static KInstance * s_instance;
+    static TDEInstance * s_instance;
 };
 
 K_EXPORT_COMPONENT_FACTORY (libkmplayerpart, KMPlayerFactory)
 
-KInstance *KMPlayerFactory::s_instance = 0;
+TDEInstance *KMPlayerFactory::s_instance = 0;
 
 KDE_NO_CDTOR_EXPORT KMPlayerFactory::KMPlayerFactory () {
-    s_instance = new KInstance ("kmplayer");
+    s_instance = new TDEInstance ("kmplayer");
 }
 
 KDE_NO_CDTOR_EXPORT KMPlayerFactory::~KMPlayerFactory () {
@@ -138,7 +138,7 @@ static bool getBoolValue (const TQString & value) {
 
 KDE_NO_CDTOR_EXPORT KMPlayerPart::KMPlayerPart (TQWidget * wparent, const char *wname,
                     TQObject * parent, const char *name, const TQStringList &args)
- : PartBase (wparent, wname, parent, name, new KConfig ("kmplayerrc")),
+ : PartBase (wparent, wname, parent, name, new TDEConfig ("kmplayerrc")),
    m_master (0L),
    m_browserextension (new KMPlayerBrowserExtension (this)),
    m_liveconnectextension (new KMPlayerLiveConnectExtension (this)),
@@ -160,11 +160,11 @@ KDE_NO_CDTOR_EXPORT KMPlayerPart::KMPlayerPart (TQWidget * wparent, const char *
             m_browserextension,
             TQT_SLOT (slotRequestOpenURL (const KURL &, const TQString &)));
 #endif
-    /*KAction *playact =*/ new KAction(i18n("P&lay"), TQString ("player_play"), KShortcut (), this, TQT_SLOT(play ()), actionCollection (), "play");
-    /*KAction *pauseact =*/ new KAction(i18n("&Pause"), TQString ("player_pause"), KShortcut (), this, TQT_SLOT(pause ()), actionCollection (), "pause");
-    /*KAction *stopact =*/ new KAction(i18n("&Stop"), TQString ("player_stop"), KShortcut (), this, TQT_SLOT(stop ()), actionCollection (), "stop");
-    new KAction (i18n ("Increase Volume"), TQString ("player_volume"), KShortcut (), this, TQT_SLOT (increaseVolume ()), actionCollection (), "edit_volume_up");
-    new KAction (i18n ("Decrease Volume"), TQString ("player_volume"), KShortcut (), this, TQT_SLOT (decreaseVolume ()), actionCollection (), "edit_volume_down");
+    /*TDEAction *playact =*/ new TDEAction(i18n("P&lay"), TQString ("media-playback-start"), TDEShortcut (), this, TQT_SLOT(play ()), actionCollection (), "play");
+    /*TDEAction *pauseact =*/ new TDEAction(i18n("&Pause"), TQString ("media-playback-pause"), TDEShortcut (), this, TQT_SLOT(pause ()), actionCollection (), "pause");
+    /*TDEAction *stopact =*/ new TDEAction(i18n("&Stop"), TQString ("media-playback-stop"), TDEShortcut (), this, TQT_SLOT(stop ()), actionCollection (), "stop");
+    new TDEAction (i18n ("Increase Volume"), TQString ("player_volume"), TDEShortcut (), this, TQT_SLOT (increaseVolume ()), actionCollection (), "edit_volume_up");
+    new TDEAction (i18n ("Decrease Volume"), TQString ("player_volume"), TDEShortcut (), this, TQT_SLOT (decreaseVolume ()), actionCollection (), "edit_volume_down");
     Source * urlsource = m_sources ["urlsource"];
     KMPlayer::ControlPanel * panel = m_view->controlPanel ();
     TQStringList::const_iterator it = args.begin ();
@@ -285,7 +285,7 @@ KDE_NO_CDTOR_EXPORT KMPlayerPart::KMPlayerPart (TQWidget * wparent, const char *
             // else showcaptioning/showgotobar/showpositioncontrols/showtracker
             } else if (name == TQString::fromLatin1("console")) {
                 m_group = value.isEmpty() ? TQString::fromLatin1("_anonymous") : value;
-            } else if (name == TQString::fromLatin1("__khtml__pluginbaseurl")) {
+            } else if (name == TQString::fromLatin1("__tdehtml__pluginbaseurl")) {
                 m_docbase = KURL (value);
             } else if (name == TQString::fromLatin1("src")) {
                 m_src_url = value;
@@ -298,7 +298,7 @@ KDE_NO_CDTOR_EXPORT KMPlayerPart::KMPlayerPart (TQWidget * wparent, const char *
 	    }
             // volume/clicktoplay/transparentatstart/animationatstart
             // autorewind/displaysize/border
-            if (name.startsWith (TQString::fromLatin1 ("__khtml__")))
+            if (name.startsWith (TQString::fromLatin1 ("__tdehtml__")))
                 name = name.mid (9);
             convertNode <KMPlayer::Element> (urlsource->document ())->setAttribute (name, value);
         }
@@ -863,7 +863,7 @@ KDE_NO_CDTOR_EXPORT KMPlayerLiveConnectExtension::KMPlayerLiveConnectExtension (
     m_started (false),
     m_enablefinish (false),
     m_evaluating (false) {
-      connect (parent, TQT_SIGNAL (started (KIO::Job *)), this, TQT_SLOT (started ()));
+      connect (parent, TQT_SIGNAL (started (TDEIO::Job *)), this, TQT_SLOT (started ()));
 }
 
 KDE_NO_CDTOR_EXPORT KMPlayerLiveConnectExtension::~KMPlayerLiveConnectExtension() {
