@@ -33,13 +33,13 @@
 #include <tqfile.h>
 #include <tqtimer.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
 #include <kled.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kprocess.h>
 #include <kprocctrl.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 
 #include "kmplayerbroadcast.h"
 #include "kmplayerprocess.h"
@@ -374,24 +374,24 @@ KDE_NO_EXPORT void KMPlayerPrefBroadcastFormatPage::slotDelete () {
 
 //-----------------------------------------------------------------------------
 
-static bool stopProcess (KProcess * process, const char * cmd = 0L) {
+static bool stopProcess (TDEProcess * process, const char * cmd = 0L) {
     if (!process || !process->isRunning ()) return true;
     do {
         if (cmd)
             process->writeStdin (cmd, strlen (cmd));
-        KProcessController::theKProcessController->waitForProcessExit (1);
+        TDEProcessController::theTDEProcessController->waitForProcessExit (1);
         if (!process->isRunning ())
             break;
         process->kill (SIGINT);
-        KProcessController::theKProcessController->waitForProcessExit (3);
+        TDEProcessController::theTDEProcessController->waitForProcessExit (3);
         if (!process->isRunning ())
             break;
         process->kill (SIGTERM);
-        KProcessController::theKProcessController->waitForProcessExit (1);
+        TDEProcessController::theTDEProcessController->waitForProcessExit (1);
         if (!process->isRunning ())
             break;
         process->kill (SIGKILL);
-        KProcessController::theKProcessController->waitForProcessExit (1);
+        TDEProcessController::theTDEProcessController->waitForProcessExit (1);
         if (process->isRunning ()) {
             return false; // give up
         }
@@ -412,7 +412,7 @@ KDE_NO_CDTOR_EXPORT KMPlayerBroadcastConfig::~KMPlayerBroadcastConfig () {
     stopServer ();
 }
 
-KDE_NO_EXPORT void KMPlayerBroadcastConfig::write (KConfig * config) {
+KDE_NO_EXPORT void KMPlayerBroadcastConfig::write (TDEConfig * config) {
     config->setGroup (strBroadcast);
     config->writeEntry (strFFServerCustomSetting, ffserversettings.list (), ';');
     TQStringList sl;
@@ -423,7 +423,7 @@ KDE_NO_EXPORT void KMPlayerBroadcastConfig::write (KConfig * config) {
     config->writeEntry (strFFServerProfiles, sl, ';');
 }
 
-KDE_NO_EXPORT void KMPlayerBroadcastConfig::read (KConfig * config) {
+KDE_NO_EXPORT void KMPlayerBroadcastConfig::read (TDEConfig * config) {
     std::for_each (ffserversettingprofiles.begin (), ffserversettingprofiles.end (), KMPlayer::Deleter<FFServerSetting>());
     ffserversettingprofiles.clear ();
     config->setGroup (strBroadcast);
@@ -470,7 +470,7 @@ TQFrame * KMPlayerBroadcastConfig::prefPage (TQWidget * parent) {
 KDE_NO_EXPORT bool KMPlayerBroadcastConfig::broadcasting () const {
     return m_ffserver_process && m_ffserver_process->isRunning ();
 }
-#include <kglobal.h>
+#include <tdeglobal.h>
 #include <kstandarddirs.h>
 
 static const char ffserverconf[] =
@@ -486,10 +486,10 @@ KDE_NO_EXPORT void KMPlayerBroadcastConfig::startServer () {
         return;
     }
     m_configpage->setCursor (TQCursor (TQt::WaitCursor));
-    m_ffserver_process = new KProcess;
+    m_ffserver_process = new TDEProcess;
     m_ffserver_process->setUseShell (true);
-    connect (m_ffserver_process, TQT_SIGNAL (processExited (KProcess *)),
-             this, TQT_SLOT (processStopped (KProcess *)));
+    connect (m_ffserver_process, TQT_SIGNAL (processExited (TDEProcess *)),
+             this, TQT_SLOT (processStopped (TDEProcess *)));
     TQString conffile = locateLocal ("data", "kmplayer/ffserver.conf");
     const char * noaudio = m_player->source ()->audioDevice ().isEmpty () ? "NoAudio" : "";
     FFServerSetting ffs;
@@ -512,9 +512,9 @@ KDE_NO_EXPORT void KMPlayerBroadcastConfig::startServer () {
     *m_ffserver_process << "ffserver -f " << conffile;
     m_ffserver_out.truncate (0);
     connect (m_ffserver_process,
-             TQT_SIGNAL (receivedStderr (KProcess *, char *, int)),
-             this, TQT_SLOT (processOutput (KProcess *, char *, int)));
-    m_ffserver_process->start (KProcess::NotifyOnExit, KProcess::Stderr);
+             TQT_SIGNAL (receivedStderr (TDEProcess *, char *, int)),
+             this, TQT_SLOT (processOutput (TDEProcess *, char *, int)));
+    m_ffserver_process->start (TDEProcess::NotifyOnExit, TDEProcess::Stderr);
     if (m_ffserver_process->isRunning ()) {
         m_configpage->startbutton->setText (i18n ("Stop"));
         m_configpage->serverled->setState (KLed::On);
@@ -531,7 +531,7 @@ KDE_NO_EXPORT void KMPlayerBroadcastConfig::stopServer () {
         KMessageBox::error (m_configpage, i18n ("Failed to end ffserver process."), i18n ("Error"));
 }
 
-KDE_NO_EXPORT void KMPlayerBroadcastConfig::processOutput (KProcess * p, char * s, int) {
+KDE_NO_EXPORT void KMPlayerBroadcastConfig::processOutput (TDEProcess * p, char * s, int) {
     if (p == m_ffserver_process)
         m_ffserver_out += TQString (s);
 }
@@ -548,8 +548,8 @@ KDE_NO_EXPORT void KMPlayerBroadcastConfig::startFeed () {
         KMessageBox::error (m_configpage, i18n ("Failed to start ffserver.\n") + m_ffserver_out, i18n ("Error"));
         goto bail_out;
     }
-    disconnect (m_ffserver_process, TQT_SIGNAL (receivedStderr (KProcess *, char *, int)),
-                this, TQT_SLOT (processOutput (KProcess *, char *, int)));
+    disconnect (m_ffserver_process, TQT_SIGNAL (receivedStderr (TDEProcess *, char *, int)),
+                this, TQT_SLOT (processOutput (TDEProcess *, char *, int)));
     if (m_ffmpeg_process)
         m_ffmpeg_process->stop ();
     delete m_ffmpeg_process;
@@ -582,15 +582,15 @@ KDE_NO_EXPORT void KMPlayerBroadcastConfig::stateChange (KMPlayer::Process::Stat
         kdDebug () << "ffmpeg process stopped " << m_endserver << endl;
         if (m_endserver && !stopProcess (m_ffserver_process)) {
             disconnect (m_ffserver_process,
-                    TQT_SIGNAL (receivedStderr (KProcess *, char *, int)),
-                    this, TQT_SLOT (processOutput (KProcess *, char *, int)));
+                    TQT_SIGNAL (receivedStderr (TDEProcess *, char *, int)),
+                    this, TQT_SLOT (processOutput (TDEProcess *, char *, int)));
             KMessageBox::error (m_configpage, i18n ("Failed to end ffserver process."), i18n ("Error"));
             processStopped (0L);
         }
     }
 }
 
-KDE_NO_EXPORT void KMPlayerBroadcastConfig::processStopped (KProcess *) {
+KDE_NO_EXPORT void KMPlayerBroadcastConfig::processStopped (TDEProcess *) {
     kdDebug () << "ffserver process stopped" << endl;
     if (m_configpage) {
         m_configpage->serverled->setState (KLed::Off);
@@ -612,7 +612,7 @@ KDE_NO_EXPORT void KMPlayerBroadcastConfig::sourceChanged (KMPlayer::Source *, K
 KDE_NO_CDTOR_EXPORT KMPlayerFFServerConfig::KMPlayerFFServerConfig () {
 }
 
-KDE_NO_EXPORT void KMPlayerFFServerConfig::write (KConfig * config) {
+KDE_NO_EXPORT void KMPlayerFFServerConfig::write (TDEConfig * config) {
     config->setGroup (strBroadcast);
     config->writeEntry (strBindAddress, bindaddress);
     config->writeEntry (strFFServerPort, ffserverport);
@@ -622,7 +622,7 @@ KDE_NO_EXPORT void KMPlayerFFServerConfig::write (KConfig * config) {
     config->writeEntry (strFeedFileSize, feedfilesize);
 }
 
-KDE_NO_EXPORT void KMPlayerFFServerConfig::read (KConfig * config) {
+KDE_NO_EXPORT void KMPlayerFFServerConfig::read (TDEConfig * config) {
     config->setGroup (strBroadcast);
     bindaddress = config->readEntry (strBindAddress, "0.0.0.0");
     ffserverport = config->readNumEntry (strFFServerPort, 8090);
