@@ -138,7 +138,7 @@ PartBase::PartBase (TQWidget * wparent, const char *wname,
     if (localbmfile != bmfile) {
         kdDebug () << "cp " << bmfile << " " << localbmfile << endl;
         TDEProcess p;
-        p << "/bin/cp" << TQString(TQFile::encodeName (bmfile)) << TQString(TQFile::encodeName (localbmfile));
+        p << "cp" << TQString(TQFile::encodeName (bmfile)) << TQString(TQFile::encodeName (localbmfile));
         p.start (TDEProcess::Block);
     }
     m_bookmark_manager = new BookmarkManager (localbmfile);
