@@ -33,13 +33,13 @@
 #include <tqpopupmenu.h>
 #include <tqfontmetrics.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <klineedit.h>
 #include <kurlrequester.h>
 #include <kcombobox.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kstandarddirs.h>
 
 #include "kmplayerpartbase.h"
@@ -522,7 +522,7 @@ KDE_NO_EXPORT TQString KMPlayerTVSource::prettyName () {
     return name;
 }
 
-KDE_NO_EXPORT void KMPlayerTVSource::write (KConfig * m_config) {
+KDE_NO_EXPORT void KMPlayerTVSource::write (TDEConfig * m_config) {
     if (!config_read) return;
     m_config->setGroup (strTV);
     m_config->writeEntry (strTVDriver, tvdriver);
@@ -541,7 +541,7 @@ KDE_NO_EXPORT void KMPlayerTVSource::readXML () {
     sync (false);
 }
 
-KDE_NO_EXPORT void KMPlayerTVSource::read (KConfig * m_config) {
+KDE_NO_EXPORT void KMPlayerTVSource::read (TDEConfig * m_config) {
     m_config->setGroup (strTV);
     tvdriver = m_config->readEntry (strTVDriver, "v4l");
 }
@@ -567,7 +567,7 @@ KDE_NO_EXPORT void KMPlayerTVSource::sync (bool fromUI) {
 
 KDE_NO_EXPORT void KMPlayerTVSource::prefLocation (TQString & item, TQString & icon, TQString & tab) {
     item = i18n ("Source");
-    icon = TQString ("source");
+    icon = TQString ("text-x-src");
     tab = i18n ("TV");
 }
 
