@@ -42,17 +42,17 @@
 #include <tqtimer.h>
 #include <tqfont.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
-#include <kfiledialog.h>
-#include <kmessagebox.h>
+#include <tdefiledialog.h>
+#include <tdemessagebox.h>
 #include <klineedit.h>
 #include <kiconloader.h>
-#include <kdeversion.h>
+#include <tdeversion.h>
 #include <kcombobox.h>
 #include <kcolorbutton.h>
 #include <kurlrequester.h>
-#include <kfontdialog.h>
+#include <tdefontdialog.h>
 
 #include "pref.h"
 #include "kmplayerpartbase.h"
@@ -71,7 +71,7 @@ KDE_NO_CDTOR_EXPORT Preferences::Preferences(PartBase * player, Settings * setti
     TQStringList hierarchy; // typo? :)
     TQVBoxLayout *vlay;
 
-    frame = addPage(i18n("General Options"), TQString(), KGlobal::iconLoader()->loadIcon (TQString ("kmplayer"), KIcon::NoGroup, 32));
+    frame = addPage(i18n("General Options"), TQString(), TDEGlobal::iconLoader()->loadIcon (TQString ("kmplayer"), TDEIcon::NoGroup, 32));
     vlay = new TQVBoxLayout(frame, marginHint(), spacingHint());
     tab = new TQTabWidget (frame);
     vlay->addWidget (tab);
@@ -84,7 +84,7 @@ KDE_NO_CDTOR_EXPORT Preferences::Preferences(PartBase * player, Settings * setti
     tab->insertTab (m_GeneralPageOutput, i18n("Output"));
     entries.insert (i18n("General Options"), tab);
 
-    frame = addPage (i18n ("Source"), TQString(), KGlobal::iconLoader()->loadIcon (TQString ("source"), KIcon::NoGroup, 32));
+    frame = addPage (i18n ("Source"), TQString(), TDEGlobal::iconLoader()->loadIcon (TQString ("text-x-src"), TDEIcon::NoGroup, 32));
     vlay = new TQVBoxLayout (frame, marginHint(), spacingHint());
     tab = new TQTabWidget (frame);
     vlay->addWidget (tab);
@@ -92,7 +92,7 @@ KDE_NO_CDTOR_EXPORT Preferences::Preferences(PartBase * player, Settings * setti
     tab->insertTab (m_SourcePageURL, i18n ("URL"));
     entries.insert (i18n("Source"), tab);
 
-    frame = addPage (i18n ("Recording"), TQString(), KGlobal::iconLoader()->loadIcon (TQString ("video"), KIcon::NoGroup, 32));
+    frame = addPage (i18n ("Recording"), TQString(), TDEGlobal::iconLoader()->loadIcon (TQString ("video-x-generic"), TDEIcon::NoGroup, 32));
     vlay = new TQVBoxLayout (frame, marginHint(), spacingHint());
     tab = new TQTabWidget (frame);
     vlay->addWidget (tab);
@@ -120,7 +120,7 @@ KDE_NO_CDTOR_EXPORT Preferences::Preferences(PartBase * player, Settings * setti
     tab->setCurrentPage (0);
     entries.insert (i18n("Recording"), tab);
 
-    frame = addPage (i18n ("Output Plugins"), TQString(), KGlobal::iconLoader()->loadIcon (TQString ("image"), KIcon::NoGroup, 32));
+    frame = addPage (i18n ("Output Plugins"), TQString(), TDEGlobal::iconLoader()->loadIcon (TQString ("image-x-generic"), TDEIcon::NoGroup, 32));
     vlay = new TQVBoxLayout(frame, marginHint(), spacingHint());
     tab = new TQTabWidget (frame);
     vlay->addWidget (tab);
@@ -160,7 +160,7 @@ KDE_NO_EXPORT void Preferences::addPrefPage (PreferencesPage * page) {
         return;
     TQMap<TQString, TQTabWidget *>::iterator en_it = entries.find (item);
     if (en_it == entries.end ()) {
-        frame = addPage (item, TQString(), KGlobal::iconLoader()->loadIcon ((icon), KIcon::NoGroup, 32));
+        frame = addPage (item, TQString(), TDEGlobal::iconLoader()->loadIcon ((icon), TDEIcon::NoGroup, 32));
         vlay = new TQVBoxLayout (frame, marginHint(), spacingHint());
         tab = new TQTabWidget (frame);
         vlay->addWidget (tab);
@@ -319,8 +319,8 @@ KDE_NO_EXPORT void PrefGeneralPageLooks::fontItemChanged (int f) {
 KDE_NO_EXPORT void PrefGeneralPageLooks::fontClicked () {
     if (fontscombo->currentItem () < int (FontSetting::last_target)) {
         TQFont myfont = fonts [fontscombo->currentItem ()].newfont;
-        int res = KFontDialog::getFont (myfont, false, this);
-        if (res == KFontDialog::Accepted) {
+        int res = TDEFontDialog::getFont (myfont, false, this);
+        if (res == TDEFontDialog::Accepted) {
             fonts [fontscombo->currentItem ()].newfont = myfont;
             fontbutton->setFont (myfont);
         }
